PAWpySeed: pawpyseed.core.noncollinear.NCLPseudoWavefunction Class Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Public Attributes | List of all members
pawpyseed.core.noncollinear.NCLPseudoWavefunction Class Reference
Inheritance diagram for pawpyseed.core.noncollinear.NCLPseudoWavefunction:
[legend]
Collaboration diagram for pawpyseed.core.noncollinear.NCLPseudoWavefunction:
[legend]

## Public Member Functions
def | __init__ (self, filename="WAVECAR", vr="vasprun.xml")
Public Member Functions inherited from pawpyseed.core.wavefunction.PseudoWavefunction
def | __init__ (self, filename="WAVECAR", vr="vasprun.xml")
def | pseudoprojection (self, band_num, basis)

## Public Attributes
| kws
| kpts
| wf_ptr
Public Attributes inherited from pawpyseed.core.wavefunction.PseudoWavefunction
| kws
| kpts
| wf_ptr
| ncl

## Detailed Description

    Class for storing noncollinear pseudowavefunction from WAVECAR file.
    Most important attribute
    is wf_ptr, a C pointer used in the C portion of the program for storing
    plane wave coefficients

    Attributes:
        kpts (np.array): nx3 array of fractional kpoint vectors,
            where n is the number of kpoints
        kws (np.array): weight of each kpoint
        wf_ptr (ctypes POINTER): c pointer to pswf_t object

## Constructor & Destructor Documentation

def pawpyseed.core.noncollinear.NCLPseudoWavefunction.__init__ | ( |  | self,
|  |  | filename = `"WAVECAR"`,
|  |  | vr = `"vasprun.xml"`
| ) |  |

## Member Data Documentation

pawpyseed.core.noncollinear.NCLPseudoWavefunction.kpts

pawpyseed.core.noncollinear.NCLPseudoWavefunction.kws

pawpyseed.core.noncollinear.NCLPseudoWavefunction.wf_ptr

The documentation for this class was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/noncollinear.py